@@ -8,9 +8,3 @@ rm -f *.tar.* *.tgz
 rm -Rf autom4te.cache
 rm -f Makefile.in aclocal.m4 configure depcomp install-sh missing
 
-
-#delete binary version too
-echo "deleting subfolder usr"
-rm -rf usr
-
-rm jammo.sh
