@@ -23,7 +23,17 @@
 #include "jammo-mentor.h"
 #include "../meam/jammo-playing-track.h"
 
+/*
+When loading composing, game mode is changed to correspond loaded composing.
+When we come back from composing, we want set game mode back to origin.
 
+-1 not defined (coming from main-menu)
+0=EASY
+1=ADVANCED
+*/
+static int previous_game_mode = -1;
+
+void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties);
 /*
 It suppose filenames are formatted in this way (will seg fault if not).
 folder/+theme+[123]+[ae]+date.
@@ -38,6 +48,18 @@ But this is callback-function for icon and we do not make icon if it doesn't cor
 */
 static gboolean cupboard_icon_clicked(TangleButton *tanglebutton, gpointer data){
 	printf("Load icon pressed\n");
+	//We do not want Mentor say "welcome to composing", when loading saved composing.
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_welcome_fi.ogg");
+
+	//We do not want Mentor to help "select theme" anymore, when player have went in composing game
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_themeselection_welcome_fi.ogg");
+	
+	//We do not want Mentor to help when first samplebutton is clicked or dragged
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_first_drag_fi.ogg");
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_first_click_fi.ogg");
+	jammo_mentor_shut_up(jammo_mentor_get_default());
+	
+	
 	ClutterActor* actor = jammo_get_actor_by_id("cupboard-view");
 	clutter_actor_hide(actor);
 
@@ -53,6 +75,16 @@ static gboolean cupboard_icon_clicked(TangleButton *tanglebutton, gpointer data)
 	char* variation_name = strtok(NULL, "+");
 	char* easy  = strtok(NULL, "+");
 	
+	//Take current game-mode.
+	if (chum_is_easy_game())
+		{
+		previous_game_mode=0;
+		}
+	else 
+		{
+		previous_game_mode=1;
+		}
+	//Change game mode to correspond loaded
 	if (strncmp(easy,"e",1)==0)
 		chum_set_easy_game(TRUE); //e=easy
 	else //if (strncmp(easy,"a",1)==0) //it is safer to use advanced if this is not clear
@@ -179,6 +211,16 @@ static gboolean cupboard_song_icon_clicked(TangleButton *tanglebutton, gpointer
 This will also check and load icons for savings.
 */
 void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	//When ending composing started from cupboard, we come back to this function.
+	//Set easy/advanced state back to what it was before loading compositions.
+	if (previous_game_mode==0)
+		chum_set_easy_game(TRUE);
+	else if (previous_game_mode==1)
+		chum_set_easy_game(FALSE);
+	//-1 means we are not coming from composing, but from mainmenu
+	//Set it to -1, if we now go to mainmenu
+	previous_game_mode=-1;
+		
 	//Scrolling area for icons
 	ClutterActor* scrolling_actor = NULL;
 	
@@ -233,7 +275,7 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 
 
 		icon = tangle_button_new_with_background_actors(clutter_texture_new_from_file(icon_filename, NULL), clutter_texture_new_from_file(icon_filename, NULL));
-		g_object_set(icon,"depth-position", -1, "width", 60.0, "height", 60.0, "x", 50.0,  "y", 20+counter1*95.0, NULL);
+		g_object_set(icon,"depth-position", -1, "width", 60.0, "height", 60.0, "x", 50.0,  "y", 20+counter1*94.0, NULL);
 		
 		clutter_container_add(CLUTTER_CONTAINER(container_for_saved_icons), icon, NULL);
 		clutter_actor_set_reactive(icon,TRUE);
@@ -304,6 +346,8 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 	clutter_actor_set_size(scrolling_actor, 310.0, counter*94.0<376.0?counter*94.0:376.0);
 	g_object_set(scrolling_actor,"depth-position", -1,NULL);
 	clutter_container_add_actor(CLUTTER_CONTAINER(jammo_get_actor_by_id("cupboard-view")), scrolling_actor);
+	
+	cupboard_door_clicked(NULL,NULL,NULL,NULL);
 }
 
 void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
@@ -311,8 +355,8 @@ void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *t
 	ClutterActor* actor2;
 	ClutterAnimation* animation;
 	ClutterAnimation* animation2;
-	gchar* filename;
-	JammoSample* sample;
+	//gchar* filename;
+	//JammoSample* sample;
 	
 	actor = jammo_get_actor_by_id("cupboard-leftdoor");
 	g_assert(actor != NULL);
@@ -323,20 +367,19 @@ void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *t
 	if ((animation = clutter_actor_get_animation(actor))) {
 		clutter_animation_completed(animation);
 	} else {
-		animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 2750, "rotation-angle-y", -150.0, "x", 217.0, NULL);
-		//g_signal_connect(animation, "completed", G_CALLBACK(finalize_welcome), NULL);
-		
+		animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 5000, "rotation-angle-y", -150.0, "x", 217.0, NULL);
+		/*
 		filename = g_strdup_printf("%s/door_opening.wav",DATA_DIR);
 		sample = jammo_sample_new_from_file(filename);
 		g_free(filename);
 		jammo_sample_play(sample);
-		g_object_unref(sample);
+		g_object_unref(sample);*/
 	}
 	
 if ((animation2 = clutter_actor_get_animation(actor2))) {
 		clutter_animation_completed(animation2);
 	} else {
-		animation2 = clutter_actor_animate(actor2, CLUTTER_LINEAR, 2750, "rotation-angle-y", 150.0, "x", 490.0, NULL);
+		animation2 = clutter_actor_animate(actor2, CLUTTER_LINEAR, 5000, "rotation-angle-y", 150.0, "x", 490.0, NULL);
 	}
 
 }
