@@ -11,6 +11,7 @@
 #include "jammo-sample-button.h"
 #include "jammo-track-view.h"
 #include <string.h>
+#include "jammo-mentor.h"
 
 G_DEFINE_TYPE(JammoSampleButton, jammo_sample_button, TANGLE_TYPE_DRAGGABLE_ACTOR);
 
@@ -232,6 +233,11 @@ static void jammo_sample_button_init(JammoSampleButton* sample_button) {
 	sample_button->priv = G_TYPE_INSTANCE_GET_PRIVATE(sample_button, JAMMO_TYPE_SAMPLE_BUTTON, JammoSampleButtonPrivate);
 }
 
+
+static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_first_click_fi.ogg");
+}
+
 static gboolean on_clicked(TangleButton* button, gpointer user_data) {
 	JammoSampleButton* sample_button;
 	
@@ -239,6 +245,7 @@ static gboolean on_clicked(TangleButton* button, gpointer user_data) {
 
 	jammo_sample_stop_all();
 	jammo_sample_play(sample_button->priv->sample);
+	g_signal_connect(sample_button->priv->sample, "stopped", G_CALLBACK(on_sample_stopped), NULL);
 	
 	return FALSE;
 }
