@@ -237,21 +237,22 @@ int main(int argc, char** argv) {
 	return 0;
 }
 
+static void mentor_say_easy(TangleActor *actor, ClutterActorBox *arg1, gpointer user_data){
+	jammo_mentor_speak(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_easy_selected_fi.ogg" );
+}
+
+
+static void mentor_say_advanced(TangleActor *actor, ClutterActorBox *arg1, gpointer user_data){
+	jammo_mentor_speak(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_advanced_selected_fi.ogg");
+}
+
+
+
 void jammo_easy_changed(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties) {
 	ClutterActor* ct =CLUTTER_ACTOR(source);
 	const gchar* name = clutter_actor_get_name(ct);
 	printf("easy/advanced clicked. get_name: '%s'\n",name);
 
-	if (strcmp(name,"easy")==0)
-		{
-		chum_set_easy_game(TRUE);
-		jammo_mentor_speak(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_easy_selected_fi.ogg");
-		}
-	else if (strcmp(name,"advanced")==0)
-		{
-		chum_set_easy_game(FALSE);
-		jammo_mentor_speak(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_advanced_selected_fi.ogg");
-		}
 
 	ClutterActor* button;
 	ClutterActor* texture;
@@ -261,6 +262,22 @@ void jammo_easy_changed(TangleAction *action, GObject *source, const gchar *trig
 	texture = jammo_get_actor_by_id(new_name);
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), texture);
 
+	ClutterActor* view = jammo_get_actor_by_id("main-menu-view");
+	//clutter_actor_show(view); //no need to call show, it is handled via json
+	
+	if (strcmp(name,"easy")==0)
+		{
+		chum_set_easy_game(TRUE);
+		g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_easy), NULL);
+		}
+	else if (strcmp(name,"advanced")==0)
+		{
+		chum_set_easy_game(FALSE);
+		g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_advanced), NULL);
+	
+		}
+
+
 }
 
 
