@@ -8,6 +8,7 @@
 #include "jammo-mentor.h"
 #include <math.h> //sin
 #include <chum/jammo-cursor.h>
+#include "trafficlight_dialog.h"
 
 
 static JammoSequencer* composing_sequencer;
@@ -18,16 +19,12 @@ static ClutterActor* view_to_go_when_end; //After start this points themeselecti
 
 static gchar* prefix_for_saving; //This will contain theme-name, -variation and easy/advanced-mode
 
-/*
-Saves only bottom track_view. TODO
-*/
+
 static gboolean save_composition() { 
 	printf("Saving composition\n");
 	FILE *ofp;
 	gchar *outputFilename;
 
-	// TODO: use date and timestamp for filenames
-	//outputFilename = g_strdup_printf("%s/%s.txt", COMPOSITIONS_DIRECTORY,prefix_for_saving);
 	outputFilename = g_strdup_printf("%s/last_composition.txt", JAMMO_DIRECTORY);
 
 	ofp = fopen(outputFilename, "w");
@@ -99,87 +96,42 @@ static gboolean save_composition() {
 
 
 
-static void close_themeselection(gpointer data){
-	TangleView* view = TANGLE_VIEW(data);
-
-	tangle_actor_destroy_animated(TANGLE_ACTOR(view));
-	//tangle_actor_hide_animated(TANGLE_ACTOR(view));
+static void close_themeselection(){
+	clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("main-views-widget")), tangle_actor_hide_animated, NULL);
 	clutter_actor_show(view_to_go_when_end);
-	
 }
 
-static gboolean yes_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
-	printf("yes selected\n");
+
+
+static gboolean yes_save_clicked ( gpointer data) {
+	printf("yes_save selected\n");
 	save_composition();
 	jammo_mentor_speak(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_save_confirmed_fi.ogg");
 	
-	close_themeselection(data);
+	close_themeselection();
 	return FALSE;
 }
 
-static gboolean no_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
-	printf("no selected\n");
-	close_themeselection(data);
+static gboolean no_save_clicked ( gpointer data) {
+	printf("no_save selected\n");
+	close_themeselection();
 	return FALSE;
 }
 
 
-static gboolean cancel_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
-	printf("cancel selected\n");
-	
-	tangle_actor_destroy_animated(TANGLE_ACTOR(data));
-	return FALSE;
-}
-
-static ClutterColor transparency_color = { 0, 0, 0, 0xdd };
-static ClutterColor *get_transparency_color(){ return &transparency_color; }
- 
-static void asking_for_saving(ClutterActor* view, gpointer data){
-	jammo_mentor_speak(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_ask_for_saving_composing_fi.ogg");
-	jammo_mentor_set_idle_speech(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_ask_for_saving_composing_fi.ogg");
-
-	ClutterActor* container_for_asking = tangle_widget_new(); //TANGLEWIDGET
-
-	ClutterActor* box=clutter_rectangle_new_with_color (get_transparency_color());
-	clutter_actor_set_size (box, 800,480);
-	clutter_actor_set_position (box, 0, 0); 
-	clutter_actor_show (box);
-	clutter_actor_set_reactive(box,TRUE);
-	clutter_container_add_actor (CLUTTER_CONTAINER (container_for_asking), box);
-
-	ClutterActor* no_button;
-	no_button=clutter_texture_new_from_file("/opt/jammo/buttons/no-button.png", NULL);
-	g_object_set(no_button, "x", 303.0,  "y", 60.0, NULL);
-	clutter_container_add(CLUTTER_CONTAINER(container_for_asking), no_button, NULL);
-	clutter_actor_set_reactive(no_button,TRUE);
-	g_signal_connect (no_button, "button-press-event", G_CALLBACK (no_clicked),data);
-
-	ClutterActor* yes_button;
-	yes_button=clutter_texture_new_from_file("/opt/jammo/buttons/yes-button.png", NULL);
-	g_object_set(yes_button, "x", 300.0,  "y", 241.0, NULL);
-	clutter_container_add(CLUTTER_CONTAINER(container_for_asking), yes_button, NULL);
-	clutter_actor_set_reactive(yes_button,TRUE);
-	g_signal_connect (yes_button, "button-press-event", G_CALLBACK (yes_clicked),data);
-
-	
-	ClutterActor* cancel_button;
-	cancel_button=clutter_texture_new_from_file("/opt/jammo/cross_icon.png", NULL);
-	g_object_set(cancel_button, "x", 719.0,  "y", 16.0, NULL);
-	clutter_container_add(CLUTTER_CONTAINER(container_for_asking), cancel_button, NULL);
-	clutter_actor_set_reactive(cancel_button,TRUE);
-	g_signal_connect (cancel_button, "button-press-event", G_CALLBACK (cancel_clicked),container_for_asking);
-
-	
-	clutter_container_add(CLUTTER_CONTAINER(view),container_for_asking, NULL);
-}
-
 /*
 This is called when user click 'cross' / 'back_to_theme_selection'
 Give view to hide as parameter.
 */
 static void back_to_theme_selection_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
+	trafficlight_dialog(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(actor))),
+                      "/opt/jammo/mentor_speech/mentor_ask_for_saving_composing_fi.ogg",
+                      "/opt/jammo/mentor_speech/mentor_ask_for_saving_composing_fi.ogg",
+                      yes_save_clicked,NULL,
+                      no_save_clicked, NULL
+                     );
+
 	jammo_sequencer_stop(composing_sequencer);
-	asking_for_saving(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(actor))),data);
 }
 
 
@@ -270,6 +222,31 @@ static void menu_clicked(ClutterTexture *actor, ClutterEvent *event, gpointer us
 }
 
 
+static void on_cursor_notify_x(GObject* object, GParamSpec* param_spec, gpointer user_data) {
+	TangleVault* vault;
+	TangleScrollingActor* scrolling_actor;
+	JammoCursor* cursor;
+	gfloat x, visible, offset, max;
+	
+	vault = TANGLE_VAULT(user_data);
+	tangle_vault_get(vault, 2, TANGLE_TYPE_SCROLLING_ACTOR, &scrolling_actor, JAMMO_TYPE_CURSOR, &cursor);
+	g_object_get(object, "x", &x, NULL);
+	g_object_get(scrolling_actor, "width", &visible, "scrolling-offset-x", &offset, "scrolling-width", &max, NULL);
+	if (x < offset) {
+		offset = x - visible + 80.0;
+		if (offset < 0.0) {
+			offset = 0.0;
+		}
+		clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-x", offset, NULL);	
+	} else if (x > offset + visible - 80.0) {
+		offset += 160.0;
+		if (offset > max) {
+			offset = max;
+		}
+		clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-x", offset, NULL);
+	}
+}
+
 
 static gboolean on_play_button_clicked(TangleButton* tanglebutton, gpointer sequencer){
 	const gchar* name = clutter_actor_get_name (CLUTTER_ACTOR(tanglebutton));
@@ -284,6 +261,7 @@ static gboolean on_play_button_clicked(TangleButton* tanglebutton, gpointer sequ
 		printf("Play button pressed (play)\n");
 		tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 
+		jammo_sample_stop_all();
 		jammo_sequencer_play(JAMMO_SEQUENCER(sequencer));
 
 		tangle_button_set_normal_background_actor(tanglebutton,clutter_texture_new_from_file("/opt/jammo/buttons/stop-button.png", NULL));
@@ -301,8 +279,28 @@ static gboolean on_play_button_clicked(TangleButton* tanglebutton, gpointer sequ
 	return FALSE;
 }
 
+static gboolean yes_ready_clicked (gpointer data) {
+	printf("yes_ready selected\n");
+	//Ask saving
+	trafficlight_dialog(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(data))),
+                      "/opt/jammo/mentor_speech/mentor_ask_for_saving_composing_fi.ogg",
+                      "/opt/jammo/mentor_speech/mentor_ask_for_saving_composing_fi.ogg",
+                      yes_save_clicked,NULL,
+                      no_save_clicked, NULL
+                     );
+	return FALSE;
+}
+
+static gboolean no_ready_clicked ( gpointer data) {
+	printf("no_ready selected\n");
+	return FALSE;
+}
 
 static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer play_button) {
+	const gchar* last_state_of_button = clutter_actor_get_name(CLUTTER_ACTOR(play_button));
+	if (strncmp(last_state_of_button,"play",4)==0) //False alert
+		return;
+	
 	printf("Sequencer stopped\n");
 	tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
 	GList *timeline;
@@ -310,13 +308,24 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer play_button
 		{
 		clutter_timeline_start(CLUTTER_TIMELINE(timeline->data));
 		}
+
 	//Change button to play
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(play_button),clutter_texture_new_from_file("/opt/jammo/buttons/play-button.png", NULL));
 	tangle_button_set_interactive_background_actor(TANGLE_BUTTON(play_button),clutter_texture_new_from_file("/opt/jammo/buttons/play-button.png", NULL));
 	clutter_actor_set_name(CLUTTER_ACTOR(play_button),"play");
+	
+	
+	
+	trafficlight_dialog(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(play_button))),
+                      "/opt/jammo/mentor_speech/mentor_composing_is_it_ready.ogg",
+                      "/opt/jammo/mentor_speech/mentor_composing_is_it_ready.ogg",
+                      yes_ready_clicked,play_button,
+                      no_ready_clicked, NULL
+                     );
 }
 
 
+
 gboolean themeselection_load(gpointer data) {
 	gchar* inputFilename = (gchar*) data;
 	printf("Themeselection: Loading composition in file '%s'\n",inputFilename);
@@ -459,6 +468,23 @@ static ClutterActor* create_soundfamily_button(const gchar* theme_name, const gc
 	return widget;
 }
 
+static gboolean first_time_transition_completed=TRUE;
+static gulong handler_for_view_transition;
+static void quitting_composing(TangleActor *actor, ClutterActorBox *arg1, ClutterActorBox *arg2, gpointer sequencer){
+	if (first_time_transition_completed)
+		{
+		printf("showing composing view\n");
+		first_time_transition_completed=FALSE;
+		}
+	else
+		{
+		printf("hiding -> destroy\n");
+		g_signal_handler_disconnect (actor,handler_for_view_transition);
+		clutter_actor_destroy(actor);
+		first_time_transition_completed=TRUE; //For next round.
+		}
+}
+
 #define WIDTH_OF_SLOT 40.0
 void themeselection_start_theme(const gchar* name, int variation, ClutterActor* where_to_go_after){
 	view_to_go_when_end = where_to_go_after; //We set this static ClutterActor, so we know where to go when composition game is quitted.
@@ -485,6 +511,7 @@ void themeselection_start_theme(const gchar* name, int variation, ClutterActor*
 	//Make new view and put it to 'main'-view.
 	ClutterActor* view;
 	if ((view = tangle_view_new())) {
+		handler_for_view_transition = g_signal_connect(view, "transition-completed", G_CALLBACK(quitting_composing), NULL);
 		g_object_set(view, "background-actor", background, NULL);	
 		ClutterActor* mainview;
 		if ((mainview = jammo_get_actor_by_id("main-views-widget"))){
@@ -519,13 +546,15 @@ void themeselection_start_theme(const gchar* name, int variation, ClutterActor*
 	
 	int disabled_slots_for_begin = 0;
 	int disabled_slots_for_end = 0;
-	float tempo_factory = 4;    //4 is default
-
+	int tempo_factory = 4;    //4 is default
+	int beats_per_minute=90; //This value should be overwritten.
+	
 	//Advanced game sets this to TRUE
 	gboolean use_two_tracks=FALSE;
 
 	if (chum_is_easy_game()) {
 	backing_track_filepath = g_strdup_printf("%s/%s/%d/backing_track.wav", THEMES_DIR, name, tempo_table[variation]);
+	beats_per_minute = tempo_table[variation];
 		
 	//Add samplebuttons. There are three themes, and each has three variations.
 	if (strncmp(name,"fantasy",7)==0 && variation==1){
@@ -641,7 +670,7 @@ else { //advanced
 	//Make buttons and containers for samplebuttons.
 	soundfamily[0] = create_soundfamily_button(name,"rhythmic_icon.png", 296.0, 103.0,TANGLE_WIDGET(view));
 	soundfamily[1] = create_soundfamily_button(name,"melodic_icon.png",  101.0, 164.0,TANGLE_WIDGET(view));
-	soundfamily[2] = create_soundfamily_button(name,"harmonic_icon.png", 631.0, 203.0,TANGLE_WIDGET(view));
+	soundfamily[2] = create_soundfamily_button(name,"harmonic_icon.png", 631.0, 199.0,TANGLE_WIDGET(view));
 	soundfamily[3] = create_soundfamily_button(name,"effect_icon.png",   548.0,  26.0,TANGLE_WIDGET(view));
 
 	if (strncmp(name,"fantasy",7)==0){
@@ -676,19 +705,21 @@ else { //advanced
 	if (variation==1)
 		{
 		background_color_code = "rrrrrrrrbbbbbbbbrrrrrrrrbbbbbbbbrrrrrrrr"; //'rhythmic'
-		tempo_factory=5;
+		tempo_factory=3;
 		}
 	if (variation==2)
 		{
 		background_color_code = "bbbbvvvvbbbbvvvvrrrrbbbbvvvvbbbbvvvvrrrr";  //'strings'
-		tempo_factory=4;   //This is not correct. FIXME. It is not 3,4,5,6
+		tempo_factory=3;
 		}
 	if (variation==3)
 		{
 		background_color_code = "vvvvbbbbvvvvbbbbvvvvbbbbllllvvvvvvvv####";  //'synth'
 		tempo_factory=3;
-		disabled_slots_for_end = 4;
+		disabled_slots_for_end = 3;
 		}
+	beats_per_minute = 90;  //All advanced fantasy variations use same set of samples, so they have same bpm
+	
 	}
 	
 	else if (strncmp(name,"animal",6)==0){
@@ -723,7 +754,7 @@ else { //advanced
 	if (variation==1)
 		{
 		background_color_code = "ggggyyyyvvvvyyyygggggggg##"; //'drumming/percussion'
-		tempo_factory=6;
+		tempo_factory=5;
 		}
 	if (variation==2)
 		{
@@ -733,10 +764,11 @@ else { //advanced
 	if (variation==3)
 		{
 		background_color_code = "yyyyggggyyyyggggyyyygggg##";  //'marimba'
-		tempo_factory=4;
+		tempo_factory=5;
 		}
 		
 	disabled_slots_for_end = 2; //each variations has same
+	beats_per_minute = 110;  //All advanced animal variations use same set of samples, so they have same bpm
 	}
 
 
@@ -749,11 +781,11 @@ else { //advanced
 	create_samplebutton( "city","advanced","bucket_5.png",  "Rh_140__44_2_rockdrums2.wav",   396.0, 103.0,TANGLE_WIDGET(soundfamily[0]));
 
 	//Melodic loops 
-	create_samplebutton("city","advanced","guitar_1.png",  "Me_140_D_44_2_bass2.wav",     120.0,  80.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("city","advanced","guitar_2.png",  "Me_140_D_44_2_guitar2.wav",    51.0, 110.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("city","advanced","guitar_3.png",  "Me_140_F_44_2_guitar1.wav",   190.0, 204.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("city","advanced","guitar_4.png",  "Me_140_F_44_2_synth.wav",     190.0, 120.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("city","advanced","guitar_5.png",  "Me_140_G_44_2_bass1.wav",     190.0,  35.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_1.png",  "Me_140_D_44_2_bass2.wav",     140.0,  80.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_2.png",  "Me_140_D_44_2_guitar2.wav",    71.0,  80.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_3.png",  "Me_140_F_44_2_guitar1.wav",   210.0, 204.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_4.png",  "Me_140_F_44_2_synth.wav",     210.0, 120.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_5.png",  "Me_140_G_44_2_bass1.wav",     210.0,  35.0,TANGLE_WIDGET(soundfamily[1]));
 
 	//Harmonic loops 
 	create_samplebutton( "city","advanced", "cycle_5.png", "Ha_140_C_44_2_synth2.wav",      716.0, 203.0,TANGLE_WIDGET(soundfamily[2]));
@@ -777,15 +809,16 @@ else { //advanced
 	if (variation==2)
 		{
 		background_color_code = "rrrrrrrrooooyyyyyyyyrrrrrrrryyyyyyyyoooo##";  //'guitar'
-		tempo_factory=3;
+		tempo_factory=4;
 		}
 	if (variation==3)
 		{
 		background_color_code = "rrrroooorrrroooorrrroooorrrroooorrrroooo##";  //'synth'
-		tempo_factory=2.5; //This is just guess. FIXME. This is also only reason why tempo_factory is not integer.
+		tempo_factory=4;
 		}
 		
 	disabled_slots_for_end = 2; //each variations has same
+	beats_per_minute = 140;  //All advanced city variations use same set of samples, so they have same bpm
 	}
 		
 		
@@ -823,20 +856,20 @@ if (use_two_tracks) y_offset=80;
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), container_for_backingtrack_blocks, NULL);
 	
 	//Tune width of containers
-	clutter_actor_set_size(container_for_backingtrack_blocks,number_of_slots*WIDTH_OF_SLOT, 40.0);
+	clutter_actor_set_size(container_for_backingtrack_blocks,number_of_slots*WIDTH_OF_SLOT, 38.0);
 	clutter_actor_set_size(container_for_tracks,number_of_slots*WIDTH_OF_SLOT, 120.0+y_offset); //track is 80 and backingtrack is 40
 	
 
-	printf("tempo_factory (time_sig): %f\n",tempo_factory);
-	
+	printf("tempo_factory (time_sig): %d, beats_per_minute: %d\n",tempo_factory,beats_per_minute);
+
 	//Bottom track. Below of this there will be place for scrollbar.
 	JammoEditingTrack* editing_track_theme = jammo_editing_track_new();
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme));
-	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots,1000000000L/tempo_table[variation]*60*tempo_factory, WIDTH_OF_SLOT);
+	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots,1000000000L/beats_per_minute*60*tempo_factory, WIDTH_OF_SLOT);
 	g_object_set(track_view, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view, TRUE);
 	g_object_set(track_view, "line-every-nth-slot", 2, NULL);
-	clutter_actor_set_position(track_view, 0.0, 0.0+y_offset);
+	clutter_actor_set_position(track_view, 0.0, 2.0+y_offset);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), track_view, NULL);
 
 	bottom_track_view = JAMMO_TRACK_VIEW(track_view); //This is needed when loading/saving
@@ -846,11 +879,11 @@ if (use_two_tracks) y_offset=80;
 	//Upper track.
 	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new();
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme2));
-	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots,1000000000L/tempo_table[variation]*60*tempo_factory, WIDTH_OF_SLOT);
+	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots,1000000000L/beats_per_minute*60*tempo_factory, WIDTH_OF_SLOT);
 	g_object_set(track_view2, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view2, TRUE);
 	g_object_set(track_view2, "line-every-nth-slot", 2, NULL);
-	clutter_actor_set_position(track_view2, 0.0, 0.0);
+	clutter_actor_set_position(track_view2, 0.0, 2.0);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), track_view2, NULL);
 	
 	upper_track_view = JAMMO_TRACK_VIEW(track_view2); //This is needed when loading/saving
@@ -864,7 +897,7 @@ if (use_two_tracks) y_offset=80;
 	clutter_container_add_actor(CLUTTER_CONTAINER(view), scrolling_actor);
 
 
-
+	//printf("number_of_slots =%d  , WIDTH_OF_SLOT = %f\n",number_of_slots , WIDTH_OF_SLOT);
 
 	//Play-button
 	ClutterActor *play_button;
@@ -880,13 +913,19 @@ if (use_two_tracks) y_offset=80;
 	ClutterColor red = { 255, 0, 0, 128 };
 	ClutterActor* texture;
 	ClutterActor* cursor;
+	
 	texture = clutter_rectangle_new_with_color(&red);
-	clutter_actor_set_size(texture, 10.0, 78.0);
+	clutter_actor_set_size(texture, 10.0, 80.0 +y_offset);
 	cursor = jammo_cursor_new(sequencer, texture);
 	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
 	clutter_actor_set_position(cursor, 0.0, 0.0);
 	clutter_actor_set_size(cursor, number_of_slots*WIDTH_OF_SLOT, 80.0);
 	clutter_container_add_actor(CLUTTER_CONTAINER(container_for_tracks), cursor);
+
+	TangleVault* vault;
+
+	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLLING_ACTOR, scrolling_actor, JAMMO_TYPE_CURSOR, cursor);
+	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
 }
 
 
