@@ -34,6 +34,7 @@ enum {
 };
 
 enum {
+	STARTED,
 	STOPPED,
 	LAST_SIGNAL
 };
@@ -42,6 +43,8 @@ struct _JammoSequencerPrivate {
 	GstElement* pipeline;
 	GstElement* adder;
 	GList* tracks;
+	guint64 duration;
+	
 	guint ready : 1;
 	guint playing : 1;
 };
@@ -88,6 +91,7 @@ gboolean jammo_sequencer_is_ready(JammoSequencer* sequencer) {
 void jammo_sequencer_play(JammoSequencer* sequencer) {
 	if (sequencer->priv->ready) {
 		gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PLAYING);
+		g_signal_emit(sequencer, signals[STARTED], 0);
 	}
 	sequencer->priv->playing = TRUE;
 }
@@ -178,7 +182,10 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 			gst_element_link(element, sequencer->priv->adder);
 			gst_object_unref(pad);
 		}
+
+		sequencer->priv->duration = 0;
 		g_signal_connect(track, "notify::duration", G_CALLBACK(on_duration_notify), sequencer);
+
 		if (sequencer->priv->ready &&
 		    jammo_track_get_duration(track) == JAMMO_DURATION_INVALID) {
 			if (sequencer->priv->playing) {
@@ -201,17 +208,37 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
  * Return value: duration in nanoseconds.
  */
 guint64 jammo_sequencer_get_duration(JammoSequencer* sequencer) {
-	guint64 duration = (guint64)0;
 	GList* list;
-	guint64 d;
+	guint64 duration;
 	
-	for (list = sequencer->priv->tracks; list; list = list->next) {
-		if ((d = jammo_track_get_duration(JAMMO_TRACK(list->data))) > duration) {
-			duration = d;
+	if (sequencer->priv->duration == 0) {
+		for (list = sequencer->priv->tracks; list; list = list->next) {
+			if ((duration = jammo_track_get_duration(JAMMO_TRACK(list->data))) != JAMMO_DURATION_INVALID && duration > sequencer->priv->duration) {
+				sequencer->priv->duration = duration;
+			}
 		}
 	}
 	
-	return duration;
+	return sequencer->priv->duration;
+}
+
+/**
+ * jammo_sequencer_get_position:
+ * @sequencer: a #JammoSequencer
+ *
+ * Queries the current position of playing.
+ *
+ * Return value: position in nanoseconds.
+ */
+guint64 jammo_sequencer_get_position(JammoSequencer* sequencer) {
+	gint64 position;
+	GstFormat format = GST_FORMAT_TIME;
+
+	if (!gst_element_query_position(sequencer->priv->pipeline, &format, &position)) {
+		position = 0;
+	}
+	
+	return (guint64)position;
 }
 
 static void jammo_sequencer_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
@@ -275,6 +302,17 @@ static void jammo_sequencer_class_init(JammoSequencerClass* klass) {
 	                                "Whether the sequencer is ready to play or not",
 	                                TRUE,
 	                                G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSequencer::started:
+	 * @sequencer: the object which received the signal
+	 *
+	 * The ::started signal is emitted when the playing (of all tracks) has started.
+	 */
+	signals[STARTED] = g_signal_new("started", G_TYPE_FROM_CLASS(gobject_class),
+					       G_SIGNAL_RUN_LAST, 0,
+					       NULL, NULL,
+					       g_cclosure_marshal_VOID__VOID,
+					       G_TYPE_NONE, 0);
 	/**
 	 * JammoSequencer::stopped:
 	 * @sequencer: the object which received the signal
@@ -355,13 +393,15 @@ static gboolean on_bus_message(GstBus* bus, GstMessage* message, gpointer data)
 static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer user_data) {
 	JammoSequencer* sequencer;
 	JammoTrack* track;
+	guint64 duration;
 	gboolean ready;
 	GList* list;
 
 	sequencer = JAMMO_SEQUENCER(user_data);
 	track = JAMMO_TRACK(object);
 
-	if (jammo_track_get_duration(track) == JAMMO_DURATION_INVALID) {
+	if ((duration = jammo_track_get_duration(track)) == JAMMO_DURATION_INVALID) {
+		sequencer->priv->duration = 0;
 		if (sequencer->priv->ready) {
 			if (sequencer->priv->playing) {
 				gst_element_set_state(sequencer->priv->pipeline, GST_STATE_NULL);
@@ -369,21 +409,27 @@ static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer
 			sequencer->priv->ready = FALSE;
 			g_object_notify(G_OBJECT(sequencer), "ready");
 		}
-	} else if (!sequencer->priv->ready) {
-		ready = TRUE;
-		for (list = sequencer->priv->tracks; list; list = list->next) {
-			if (list->data != (gpointer)track &&
-			    jammo_track_get_duration(JAMMO_TRACK(list->data)) == JAMMO_DURATION_INVALID) {
-				ready = FALSE;
-				break;
-			}
+	} else {
+		if (duration > sequencer->priv->duration) {
+			sequencer->priv->duration = duration;
 		}
-		if (ready) {
-			sequencer->priv->ready = TRUE;
-			g_object_notify(G_OBJECT(sequencer), "ready");
-			if (sequencer->priv->playing) {
-				gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PLAYING);
+		if (!sequencer->priv->ready) {
+			ready = TRUE;
+			for (list = sequencer->priv->tracks; list; list = list->next) {
+				if (list->data != (gpointer)track &&
+				    jammo_track_get_duration(JAMMO_TRACK(list->data)) == JAMMO_DURATION_INVALID) {
+					ready = FALSE;
+					break;
+				}
 			}
-		}
-	}	
+			if (ready) {
+				sequencer->priv->ready = TRUE;
+				g_object_notify(G_OBJECT(sequencer), "ready");
+				if (sequencer->priv->playing) {
+					gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PLAYING);
+					g_signal_emit(sequencer, signals[STARTED], 0);
+				}
+			}
+		}	
+	}
 }
